<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Dark Theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Simple mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scientific mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deepin Calculator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
